"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const async_no_await_1 = require("../rules/async-no-await");
const ruleTester = new utils_1.ESLintUtils.RuleTester({
    parser: "@typescript-eslint/parser",
    parserOptions: {
        tsconfigRootDir: __dirname,
        project: "./tsconfig.json",
    },
});
ruleTester.run("async-no-await", async_no_await_1.default, {
    valid: [
        `function a() {
        return Promise.resolve();
      };
    async function b() {
      await a();
      return Promise.resolve();
    };`,
        `function a() {
      return Promise.resolve();
    };
    function b() {
      a();
      return Promise.resolve();
    };`,
    ],
    invalid: [
        {
            code: `
      function a() {
        return Promise.resolve();
      };
      async function b() {
        a();
        return Promise.resolve();
      };
      `,
            errors: [{ messageId: "noAwaitBeforeReturnPromise" }],
        },
        {
            code: `
      function a() {
        return Promise.resolve();
      };
      async function b() {
        a();
        return 'Not returning a Promise';
      };`,
            errors: [
                { messageId: "unnecessaryAsync" },
                { messageId: "noAwaitBeforeReturnPromise" },
            ],
        },
        {
            code: `
      function c() {
        return Promise.resolve();
      };
      async function d() {
        const result = c();
        return result;
      };`,
            errors: [{ messageId: "noAwaitBeforeReturnPromise" }],
        },
        {
            code: `
      function a() {
        return Promise.resolve();
      };
      async function b() {
        a().then(() => {});
        return Promise.resolve();
      };
      `,
            errors: [{ messageId: "noAwaitBeforeReturnPromise" }],
        },
    ],
});
